@@ -3,7 +3,7 @@
 #include "radiostation.h"
 #include "texteditautoresizer.h"
 
-const QString appVersion = "1.0.3";
+const QString appVersion = "1.0.4";
 
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent), ui(new Ui::MainWindow), quitActionPressed(false), hideWhenClosing(false)
@@ -18,6 +18,10 @@ MainWindow::MainWindow(QWidget *parent) :
     stationsDb.checkDB();
     stationsDb.initDB();
 
+    swipeGesture = new MySwipeGesture(this);
+    connect(swipeGesture,SIGNAL(handleSwipe(MySwipeGesture::SwipeDirection)),this,SLOT(handleSwipe(MySwipeGesture::SwipeDirection)));
+
+
     qDebug()<<stationsDb.getGenreList();
     qDebug()<<stationsDb.getCountryList();
     qDebug()<<stationsDb.getFullStationList(StationsDB::OrderByName);
@@ -43,6 +47,7 @@ MainWindow::MainWindow(QWidget *parent) :
     connectBluetoothControl();
     new TextEditAutoResizer(ui->cronologyTextEdit);
 
+
     setAttribute(Qt::WA_Maemo5StackedWindow);
     //setWindowFlags(Qt::Window);
 
@@ -737,4 +742,19 @@ void MainWindow::on_actionGetFavouriteList_triggered()
     populateList(stationsList);
 }
 
+bool MainWindow::event(QEvent *event)
+{
+    swipeGesture->handleEvent(event);
+    return QWidget::event(event);
+}
+
+void MainWindow::handleSwipe(MySwipeGesture::SwipeDirection direction)
+{
+    qDebug() << "swipe" << direction;
+}
+
+
+
+
+
 
