@@ -7,6 +7,7 @@
 #include "filterlistbydialog.h"
 #include "lyricswebview.h"
 #include "settingsdialog.h"
+#include "myswipegesture.h"
 
 #include <QBuffer>
 #include <QClipboard>
@@ -81,6 +82,7 @@ private slots:
     void on_actionDeleteFromFavourites_triggered();
     void on_actionGetFavouriteList_triggered();
     void on_actionAddToFavourites_triggered();
+    void handleSwipe(MySwipeGesture::SwipeDirection);
 
 private:
     Ui::MainWindow *ui;
@@ -94,6 +96,7 @@ private:
 
     StationsDB stationsDb;
     BluetoothHeadsetAdapter bluetoothAdapter;
+    MySwipeGesture *swipeGesture;
 
     LyricsWebView* lyricsWebView;
 
@@ -115,6 +118,9 @@ private:
 
     void closeEvent(QCloseEvent *event);
 
+protected:
+    bool event(QEvent *event);
+
 
 };
 
